@@ -1,6 +1,6 @@
 /*
  * POSIX library for Lua 5.1, 5.2, 5.3 & 5.4.
- * Copyright (C) 2013-2023 Gary V. Vaughan
+ * Copyright (C) 2013-2025 Gary V. Vaughan
  * Copyright (C) 2010-2013 Reuben Thomas <rrt@sc3d.org>
  * Copyright (C) 2008-2010 Natanael Copa <natanael.copa@gmail.com>
  * Clean up and bug fixes by Leo Razoumov <slonik.az@gmail.com> 2006-10-11
@@ -577,13 +577,13 @@ Receive a message from a socket.
 static int
 Precvfrom(lua_State *L)
 {
-	void *ud, *buf;
-	socklen_t salen;
-	struct sockaddr_storage sa;
-	int r;
 	int fd = checkint(L, 1);
 	size_t count = (size_t)checkinteger(L, 2);
+	ssize_t ret;
+	void *ud, *buf;
 	lua_Alloc lalloc;
+	socklen_t salen;
+	struct sockaddr_storage sa;
 
 	checknargs(L, 2);
 	lalloc = lua_getallocf(L, &ud);
@@ -594,14 +594,14 @@ Precvfrom(lua_State *L)
 		return pusherror(L, "lalloc");
 
 	salen = sizeof(sa);
-	r = recvfrom(fd, buf, count, 0, (struct sockaddr *)&sa, &salen);
-	if (r < 0)
+	ret = recvfrom(fd, buf, count, 0, (struct sockaddr *)&sa, &salen);
+	if (ret < 0)
 	{
 		lalloc(ud, buf, count, 0);
 		return pusherror(L, NULL);
 	}
 
-	lua_pushlstring(L, buf, r);
+	lua_pushlstring(L, buf, ret);
 	lalloc(ud, buf, count, 0);
 	return 1 + pushsockaddrinfo(L, sa.ss_family, (struct sockaddr *)&sa);
 }
